/*
 * File:   FirstMiwi.c
 * Author: Eric
 *
 * Created on 15 octobre 2011, 18:00
 */

#include <p18cxxx.h>
#include <p18f4550.h>
#include <delays.h>
#include <spi.h>
#include "SystemProfile.h"
#include "WirelessProtocols/MCHP_API.h"


#pragma config PLLDIV = 5		//Based on 20MHz oscillator
#pragma config CPUDIV = OSC1_PLL2

#pragma config USBDIV   = 2         // Clock source from 96MHz PLL/2
#pragma config FOSC     = HSPLL_HS
#pragma config FCMEN    = OFF
#pragma config IESO     = OFF
#pragma config PWRT     = OFF
#pragma config BOR      = ON
#pragma config BORV     = 3
#pragma config VREGEN   = ON      //USB Voltage Regulator
#pragma config WDT      = OFF
#pragma config WDTPS    = 32768
#pragma config MCLRE    = ON
#pragma config LPT1OSC  = OFF
#pragma config PBADEN   = OFF
#pragma config STVREN   = ON
#pragma config LVP      = OFF

#define LED1 LATDbits.LATD0
#define LED2 LATDbits.LATD1
#define LED3 LATCbits.LATC0
#define LED4 LATCbits.LATC1
#define LED5 LATCbits.LATC2

#define INPUT1 PORTDbits.RD2
#define INPUT2 PORTDbits.RD3
#define INPUT3 PORTDbits.RD4


#if ADDITIONAL_NODE_ID_SIZE > 0
BYTE    AdditionalNodeID[ADDITIONAL_NODE_ID_SIZE] = {0x00};
#endif

extern ACTIVE_SCAN_RESULT ActiveScanResults[ACTIVE_SCAN_RESULT_SIZE];
extern CONNECTION_ENTRY ConnectionTable[CONNECTION_SIZE];
extern BYTE TxBuffer[TX_BUFFER_SIZE];

void BoardInit(void)
{

    // primary internal oscillator
    //OSCCON = 0x7B;
    WDTCONbits.SWDTEN = 0;
    INTCONbits.GIEH = 1;
    //On autorise les interruptions 
    RFIF = 0;
    RFIE = 1;
    INTCON2bits.INTEDG2 = 0;

    CCP1CON = 0x00;
    //Congiguration des ports
    TRISC = TRISC & 0xB8;
    TRISB = 0x00;
    TRISD = 0xFC;
    //Pull up
    PORTEbits.RDPU = 1;
    INTCON2bits.RBPU = 0;
    //On valide les interruptions
    INTCONbits.GIEH = 1;
}

void main(void)
{
    char value = 0;
    BYTE i;
    BYTE noise = 0xFF;
    DWORD channelMap = 0x00000001;
    BYTE newChannel = 0x00;
    unsigned char lastLed[3];
    BYTE destinataire[MY_ADDRESS_LENGTH] = {0x31,0x32,0x87,0x67,0x04,0x33,0x22,0x11};

    BoardInit();

    LED1 = 1;
    LED2 = 1;
    LED3 = 1;
    LED4 = 1;
    LED5 = 1;


    for(i = 0; i < 3; i++)
    {
        lastLed[i] = 0x32;
    }
    //Configuration du SPI
    //Reset du miwi
    DisableIntSPI;
    CloseSPI();
    OpenSPI(SPI_FOSC_64,MODE_00,SMPMID);
    MiApp_ProtocolInit(FALSE);
    MiApp_SetChannel(16);
    value  = MiApp_NoiseDetection(0x07FFF800,10,NOISE_DETECT_ENERGY,&noise);
    newChannel = value;
    channelMap = channelMap << value;
    value = MiApp_StartConnection(START_CONN_ENERGY_SCN,10,channelMap);
    MiApp_ConnectionMode(ENABLE_ALL_CONN);
    LED2 = 0;
    while(1)
    {
        if(MiApp_MessageAvailable())
        {
            //Traitement du message
            LED1 = 0;
            if(rxMessage.PayloadSize == 3)
            {
                if(rxMessage.Payload[0] == 0x12)
                {
                    switch(rxMessage.Payload[1])
                    {
                        case 0x01:
                            LED3 = rxMessage.Payload[2];
                            break;
                        case 0x02:
                            LED4 = rxMessage.Payload[2];
                            break;
                        case 0x03:
                            LED5 = rxMessage.Payload[2];
                            break;
                    }
                }
            }
            for(i = 0; i < 8; i++)
            {
                value = rxMessage.SourceAddress[i];
            }
            MiApp_DiscardMessage();
        }
        else
        {
            if(INPUT1 != lastLed[0])
            {

                MiApp_FlushTx();
                MiApp_WriteData(0x12); //Inversion de la led 1
                MiApp_WriteData(0x01); //Inversion de la led 1
                MiApp_WriteData(INPUT1); //Inversion de la led 1
                MiApp_UnicastConnection(0,FALSE);
                lastLed[0] = INPUT1;
            }
            if(INPUT2 != lastLed[1])
            {
                MiApp_FlushTx();
                MiApp_WriteData(0x12); //Inversion de la led 1
                MiApp_WriteData(0x02); //Inversion de la led 1
                MiApp_WriteData(INPUT2); //Inversion de la led 1
                value = MiApp_UnicastAddress(destinataire,TRUE,FALSE);
                lastLed[1] = INPUT2;
            }
            if(INPUT3 != lastLed[2])
            {
                MiApp_FlushTx();
                MiApp_WriteData(0x12); //Inversion de la led 1
                MiApp_WriteData(0x03); //Inversion de la led 1
                MiApp_WriteData(INPUT3); //Inversion de la led 1
  //              MiApp_UnicastAddress(destinataire, TRUE,FALSE);
                MiApp_BroadcastPacket(FALSE);
                lastLed[2] = INPUT3;
            }
        }
    }
    return;
}
void UserInterruptHandler(void)
{
    unsigned char toto;
    toto = 0x00;
    toto = toto + 1;
}

